.First.lib <- function(library,section){
	if(!require("syskern")) 
	warning("This package requires the syskern package.") # only for is.S ?
	invisible()
}
